@@ -7,19 +7,17 @@
 import imaplib
 import unittest
 
-from imap_cli import config
-from imap_cli import status
+import imap_cli
 from imap_cli import tests
 
 
 class StatusTest(unittest.TestCase):
     def setUp(self):
-        self.ctx = config.new_context()
         imaplib.IMAP4_SSL = tests.ImapConnectionMock()
 
     def test_status(self):
-        self.ctx.mail_account = imaplib.IMAP4_SSL()
-        self.ctx.mail_account.login()
+        self.imap_account = imaplib.IMAP4_SSL()
+        self.imap_account.login()
 
-        for directory_status in status.status(self.ctx):
+        for directory_status in imap_cli.status(self.imap_account):
             assert directory_status == {'directory': "Directory_name", 'unseen': "0", 'count': "1", 'recent': "1"}
